# Importing and Exporting Transformations via Excel File
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/importing-and-exporting-transformations-via-excel-file#introduction)
  * [Permissions](https://help.sap.com/docs/leanix/ea/importing-and-exporting-transformations-via-excel-file#permissions)
  * [Exporting Transformation Items Via Excel File](https://help.sap.com/docs/leanix/ea/importing-and-exporting-transformations-via-excel-file#exporting-transformation-items-via-excel-file)
  * [Importing Transformation Items Via Excel File](https://help.sap.com/docs/leanix/ea/importing-and-exporting-transformations-via-excel-file#importing-transformation-items-via-excel-file)
  * [Updating the Data in the Spreadsheet](https://help.sap.com/docs/leanix/ea/importing-and-exporting-transformations-via-excel-file#updating-the-data-in-the-spreadsheet)
  * [Uploading File](https://help.sap.com/docs/leanix/ea/importing-and-exporting-transformations-via-excel-file#uploading-file)
  * [Reviewing Upload Status and Error Handling](https://help.sap.com/docs/leanix/ea/importing-and-exporting-transformations-via-excel-file#reviewing-upload-status-and-error-handling)


The Excel import and export feature enables efficient bulk updates, including adding, updating, and deleting transformation items. This guide provides formatting rules, error handling, and step-by-step guidance for importing and exporting data via an Excel file.
